import { Selector, t } from "testcafe";

import {
  getCurrentURL,
  isElementVisible,
} from "../utils/testUtils";

export default class LoginPage {
  constructor() {
    this.email = Selector(`#username`);
    this.password = Selector(`#password`);
    this.logInBtn = Selector(`[name="action"]`);
    this.loginPath = `https://auth.ecobee.com/`;
  }

  async pageIsLoaded() {
    await t
      .expect(getCurrentURL())
      .contains(
        this.loginPath,
        `The current url doesn't contain: ${this.loginPath}`
      );
    await t
      .expect(await isElementVisible(this.email))
      .ok("Email doesn't exist or it isn't visible");
    await t
      .expect(await isElementVisible(this.password))
      .ok("Password doesn't exist or it isn't visible");
    await t
      .expect(await isElementVisible(this.logInBtn))
      .ok("Sign in button doesn't exist or it isn't visible");
  }

  async fillOutWebLogin(email, password, otpSecret) {
    await t
      .typeText(this.email, email, { replace: true })
      .typeText(this.password, password, { replace: true })
      .click(this.logInBtn);
  }

}
