import { Selector, t } from "testcafe";
import { getCurrentURL, isElementVisible } from "../utils/testUtils";

export default class SizePage {
  constructor() {
    this.pageTitle = Selector(`[data-qa-id="page-title"]`);
    this.confirmSizeQuantityBtn = Selector(`[data-qa-id="select-sizes"]`);
    this.sizePath = `/size`;
  }

  async pageIsLoaded() {
    await t
      .expect(getCurrentURL())
      .contains(
        this.sizePath,
        `The current url doesn't contain: ${this.sizePath}`
      );
    await t
      .expect(await isElementVisible(this.pageTitle))
      .ok("Page title doesn't exist or it isn't visible");
  }

  async selectOneTwoInchFilterLength(filterSizeNumber, length) {
    const htmlElementIndex = filterSizeNumber - 1;
    const filterLength = Selector(`#filter-select-${htmlElementIndex}-length`);

    await t.click(filterLength);

    let lengthDropdownItems = Selector(`.input-select__option`);
    await t.click(lengthDropdownItems.withText(length));
  }

  async selectOneTwoInchFilterWidth(filterSizeNumber, width) {
    const htmlElementIndex = filterSizeNumber - 1;
    const filterWidth = Selector(`#filter-select-${htmlElementIndex}-width`);

    await t.click(filterWidth);

    let widthDropdownItems = Selector(`.input-select__option`);
    await t.click(widthDropdownItems.withText(width));
  }

  async selectOneTwoInchFilterThickness(filterSizeNumber, thickness) {
    const htmlElementIndex = filterSizeNumber - 1;
    const filterThickness = Selector(
      `#filter-select-${htmlElementIndex}-thickness`
    );

    await t.click(filterThickness);

    let thicknessDropdownItems = Selector(`.input-select__option`);
    await t.click(thicknessDropdownItems.withText(thickness));
  }

  async selectOneTwoInchFilterSize(filterSizeNumber, length, width, thickness) {
    await this.selectOneTwoInchFilterLength(
      filterSizeNumber,
      length[filterSizeNumber - 1]
    );
    await this.selectOneTwoInchFilterWidth(
      filterSizeNumber,
      width[filterSizeNumber - 1]
    );
    await this.selectOneTwoInchFilterThickness(
      filterSizeNumber,
      thickness[filterSizeNumber - 1]
    );
  }

  async clickConfirmSizeQuantity() {
    await t.click(this.confirmSizeQuantityBtn);
  }
}
